# -*- coding: utf-8 -*-

import argparse
import sys
from .rcp import get_poll_data, to_csv

try:
    from urllib.request import urlopen
except ImportError:
    from urllib2 import urlopen

parser = argparse.ArgumentParser()
parser.add_argument("url", nargs='+', help="The url of the polling data.")
parser.add_argument("--output", nargs="?", help="The output file name.")
args = parser.parse_args()


def main():
    for pd in args.url:
        fn = args.output if args.output else pd.rsplit('/', 1)[-1][:-5] + ".csv"
        p = get_poll_data(pd, d=False)
        if not p:
            sys.exit("No poll data found.")
        print("Downloading: %s" % fn)
        to_csv(fn, pd)


if __name__ == '__main__':
    main()



# -*- coding: utf-8 -*-

from bs4 import BeautifulSoup

try:
    from urllib.request import urlopen
except ImportError:
    from urllib2 import urlopen

import csv
import json

base = 'https://www.realclearpolitics.com'


def get_polls(q=None, p=None):
    response = urlopen('%s/epolls/latest_polls/' % base)

    soup = BeautifulSoup(response, 'html.parser')

    fp = soup.find_all("table", {"class": 'sortable'})

    polling_data = []

    for l in fp:
        cols = l.find_all('tr')
        for col in cols:
            race = col.find('td', {'class': 'lp-race'})

            if not race:
                continue

            t = race.find('a').text
            n = col.find('td', {'class': 'lp-poll'}).find('a').text

            if (q and q.lower() not in t.lower()) or (p and p.lower() not in n.lower()):
                continue

            v = {
                'url': base + race.find('a')['href'],
                'title': t,
                'poll': n,

            }
            polling_data.append(v)

    return polling_data


def get_poll_data(pd, d=True):
    if base not in pd:
        return

    response = urlopen(pd)

    soup = BeautifulSoup(response, 'html.parser')
    fp = soup.find("div", {"id": 'polling-data-full'})

    if not fp:
        return

    rows = fp.find('table', {"class": 'data'})

    p = []

    for row in rows:
        cols = row.find_all(['th', 'td'])
        p.append([ele.text.strip() for ele in cols])

    if not d:
        return p

    arr = [{
        'poll': pd,
        'data': []
    }]

    keys = p[0]

    for k in p[1:]:
        b = {}
        for i, n in enumerate(keys):
            b[n] = k[i]
        arr[0]['data'].append(b)

    return arr


def to_csv(fn, p):
    with open(fn, "w") as f:
        writer = csv.writer(f)
        writer.writerows(p)
    print("CSV created.")



# -*- coding: utf-8 -*-

import os
import sys
from shutil import rmtree

from setuptools import setup, Command

with open("README.rst", "rb") as f:
    long_descr = f.read().decode("utf-8")


class PublishCommand(Command):
    """Support setup.py publish."""

    description = 'Build and publish the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('\033[1m{0}\033[0m'.format(s))

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except:
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        os.system('{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))

        self.status('Uploading the package to PyPi via Twine…')
        os.system('twine upload dist/*')

        sys.exit()


setup(
    name="realclearpolitics",
    packages=["rcp"],
    entry_points={
        "console_scripts": ['rcp = rcp.rcp:main']
    },
    version='1.1.0',
    description="Simple script to scrape polling data from RealClearPolitics and output as .csv",
    long_description=long_descr,
    keywords=['politics', 'polls', 'rcp', 'realclearpolitics', 'web scraping'],
    author="Anthony Bloomer",
    author_email="ant0@protonmail.ch",
    url="https://github.com/AnthonyBloomer/rcp",
    install_requires=[
        'beautifulsoup4',
        'requests'
    ],
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 2.7'
    ],
    cmdclass={
        'publish': PublishCommand,
    },
)
